{
    "$graph": [
        {
            "baseCommand": "sh",
            "class": "CommandLineTool",
            "doc": "Runs west code for different input paramaters",
            "id": "#west.cwl",
            "inputs": [
                {
                    "doc": "West shell script which generates output based on inputs using docker",
                    "id": "#west.cwl/west_tool/script_file",
                    "inputBinding": {
                        "position": 1
                    },
                    "type": "File"
                },
                {
                    "doc": "Input file for west code. Can be pw.in, wstat.in",
                    "id": "#west.cwl/west_tool/input_file",
                    "inputBinding": {
                        "position": 2
                    },
                    "type": "File"
                },
                {
                    "doc": "Urls to download upf files used for pw, wstat scripts",
                    "id": "#west.cwl/west_tool/URLs",
                    "inputBinding": {
                        "position": 3
                    },
                    "type": "string"
                },
                {
                    "doc": "choose pw or wstat",
                    "id": "#west.cwl/west_tool/script_type",
                    "inputBinding": {
                        "position": 4
                    },
                    "type": "string"
                },
                {
                    "doc": "choose 2, 3, 4",
                    "id": "#west.cwl/west_tool/no_of_cores",
                    "inputBinding": {
                        "position": 5
                    },
                    "type": "int"
                }
            ],
            "label": "calculates pw.x, wstat.x and generates pw.out,wstat.out file",
            "http://schema.org/about": "West code runs pw for an input pw.in file to generate pw.out, or wstat for wstat.in with wstat.out file",
            "http://schema.org/name": "West",
            "outputs": [
                {
                    "doc": "Output File generated with west pw.x or wstat.x code",
                    "id": "#west.cwl/west_tool/west_output_file",
                    "outputBinding": {
                        "glob": "*.out"
                    },
                    "type": "File"
                }
            ]
        },
        {
            "class": "Workflow",
            "doc": "Workflow tool to generate west code",
            "id": "#main",
            "inputs": [
                {
                    "doc": "Urls to download upf files used for west scripts",
                    "id": "#main/URLs",
                    "inputBinding": {
                        "position": 3
                    },
                    "type": "string"
                },
                {
                    "doc": "Input file for west code. Can be pw.in, wstat.in",
                    "id": "#main/input_file_array",
                    "inputBinding": {
                        "position": 2
                    },
                    "type": {
                        "items": "File",
                        "type": "array"
                    }
                },
                {
                    "doc": "No of cores to run on 2 ,3 ,4",
                    "id": "#main/no_of_cores",
                    "inputBinding": {
                        "position": 5
                    },
                    "type": "int"
                },
                {
                    "doc": "West script which generates pw.out, wstat.out based on inputs",
                    "id": "#main/script_file",
                    "inputBinding": {
                        "position": 1
                    },
                    "type": "File"
                },
                {
                    "doc": "choose between pw, wstat",
                    "id": "#main/script_type_array",
                    "inputBinding": {
                        "position": 4
                    },
                    "type": {
                        "items": "string",
                        "type": "array"
                    }
                }
            ],
            "label": "Workflow tool to generates pw.out and wstat.out files",
            "outputs": [
                {
                    "id": "#main/output_file",
                    "label": "Output File generated with west code",
                    "outputSource": "#main/west_tool/west_output_file",
                    "type": {
                        "items": "File",
                        "type": "array"
                    }
                }
            ],
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "steps": [
                {
                    "doc": "runs west.cwl",
                    "in": [
                        {
                            "id": "#main/west_tool/URLs",
                            "source": "#main/URLs"
                        },
                        {
                            "id": "#main/west_tool/input_file",
                            "source": "#main/input_file_array"
                        },
                        {
                            "id": "#main/west_tool/no_of_cores",
                            "source": "#main/no_of_cores"
                        },
                        {
                            "id": "#main/west_tool/script_file",
                            "source": "#main/script_file"
                        },
                        {
                            "id": "#main/west_tool/script_type",
                            "source": "#main/script_type_array"
                        }
                    ],
                    "out": [
                        "#main/west_tool/west_output_file"
                    ],
                    "run": "#west.cwl",
                    "scatter": [
                        "#main/west_tool/script_type",
                        "#main/west_tool/input_file"
                    ],
                    "scatterMethod": "dotproduct",
                    "id": "#main/west_tool"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0"
}
